import { useState, useEffect } from "react";
import PropType from "prop-types";
import TagsInput from "react-tagsinput";
import { HelperMessage } from "@atlaskit/form";

import { Wrapper } from "./styles";

const inputProps = {
  className: "react-tagsinput-input",
  placeholder: "Pressione Enter para adicionar uma palavra-chave",
};

export const Keyword = ({ title, helperText, placeholder, name, onChange }) => {
  const [values, setValues] = useState([]);

  useEffect(() => {
    onChange(values);
  }, [onChange, values]);

  return (
    <Wrapper>
      <label htmlFor="keyword">{title}</label>
      <TagsInput
        id="keyword"
        name={name}
        value={values}
        tags={values}
        placeholder={placeholder}
        inputProps={inputProps}
        onChange={setValues}
      />
      <HelperMessage>{helperText}</HelperMessage>
    </Wrapper>
  );
};

Keyword.propType = {
  /**
   Title
   */
  title: PropType.string.isRequired,
  /**
   Name
   */
  name: PropType.string.isRequired,
  /**
   Helper text
   */
  helperText: PropType.string,
  /**
   Placeholder
   */
  placeholder: PropType.string,
  /**
   Callback function
   */
  onChange: PropType.func,
};
