import { useState } from "react";
import PropType from "prop-types";
import Button from "@atlaskit/button";

import { Select } from "../Select/Select";
import { Keyword } from "../Keyword/Keyword";

import {
  Container,
  GroupField,
  SelectField,
  KeywordField,
  ButtonField,
  ButtonWrapper,
  Content,
  Footer,
} from "./styles";

export const KeywordSearch = ({
  title,
  options,
  buttonSearchLabel,
  buttonExpandedLabel,
  buttonResumeLabel,
  onSeach,
  onCancel,
  children,
  hasConditions,
  hasKeyword,
  hasExpanded,
}) => {
  const [expanded, setExpanded] = useState(false);
  const [condition, setCondition] = useState("");
  const [keywords, setKeywords] = useState([]);

  const handleOnSeach = () => onSeach({ condition, keywords });

  const handleOnCancel = () => {
    setCondition("");
    setKeywords([]);
    setExpanded(false);
    onCancel({});
  };

  const handleOnClean = () => {
    setCondition("");
    setKeywords([]);
    window?.scrollTo(0, 0);
  };

  return (
    <Container>
      <h2>{title}</h2>
      <GroupField>
        {hasConditions && options?.length > 0 && (
          <SelectField>
            <Select
              name="condition"
              title="Condições"
              helperText="[E] mais específico - [OU] menos específico"
              options={options}
              defaultValue={options[0]}
              onChange={(e) => setCondition(e.value)}
            />
          </SelectField>
        )}
        {hasKeyword && (
          <KeywordField>
            <Keyword
              name="keyword"
              title="Palavras-chave"
              helperText="Pesquise por palavras chaves dentro do currículo dos candidatos"
              onChange={(e) => setKeywords(e)}
            />
          </KeywordField>
        )}
        {!expanded && (
          <ButtonField>
            <Button appearance="primary" onClick={handleOnSeach}>
              {buttonSearchLabel}
            </Button>
          </ButtonField>
        )}
      </GroupField>
      {hasExpanded && !expanded && (
        <ButtonWrapper>
          <Button appearance="link" onClick={() => setExpanded(true)}>
            {buttonExpandedLabel}
          </Button>
        </ButtonWrapper>
      )}
      {hasExpanded && expanded && (
        <>
          <Content>{children}</Content>
          <Footer>
            <Button appearance="subtle" onClick={() => setExpanded(false)}>
              {buttonResumeLabel}
            </Button>
            <div>
              <Button appearance="subtle" onClick={handleOnClean}>
                Limpar
              </Button>
              <Button appearance="link" onClick={handleOnCancel}>
                Cancelar
              </Button>
              <Button appearance="primary" onClick={handleOnSeach}>
                {buttonSearchLabel}
              </Button>
            </div>
          </Footer>
        </>
      )}
    </Container>
  );
};

KeywordSearch.propTypes = {
  /**
   Header title
   */
  title: PropType.string.isRequired,
  /**
   Select title
   */
  selectTitle: PropType.string,
  /**
   Label of search button
   */
  buttonSearchLabel: PropType.string,
  /**
   Label of expanded filter
   */
  buttonExpandedLabel: PropType.string,
  /**
   Label of expanded filter
   */
  buttonResumeLabel: PropType.string,
  /**
   Enable conditions Select
   */
  hasConditions: PropType.bool,
  /**
   Enable keywords Input
   */
  hasKeyword: PropType.bool,
  /**
   Enable expanded options
   */
  hasExpanded: PropType.bool,
  /**
   React children component
   */
  children: PropType.object.isRequired,
  /**
   Callback to search action 
   */
  onSeach: PropType.func.isRequired,
  /**
   Callback to cancel action
   */
  onCancel: PropType.func.isRequired,
};

KeywordSearch.defaultProps = {
  buttonSearchLabel: "Aplicar Busca",
  buttonExpandedLabel: "+ Visualizar todas as opções de filtro",
  buttonResumeLabel: "- Ocultar todas as opções de filtro",
  hasConditions: true,
  hasKeyword: true,
  hasExpanded: true,
};
