import React from "react";
import PropType from "prop-types";
import Select from "@atlaskit/select";

import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faTimes } from "@fortawesome/free-solid-svg-icons";

import { Nav, selectStyles, ButtonLink } from "./styles";

/**
- When Navigationbar is used with select option, should be added a list of options to select.
 */
export const Navigationbar = ({
  color,
  select,
  close,
  onClose,
  onSelect,
  onRedirect,
  logo,
  alt,
  options,
  closeTitle,
}) => {
  return (
    <Nav color={color} select={select} close={close}>
      <div className="content">
        <img onKeyDown={onRedirect} onClick={onRedirect} src={logo} alt={alt} />
        <div className="actions">
          {select && (
            <div className="select">
              <Select
                className="single-select"
                classNamePrefix="react-select"
                placeholder="Carregando..."
                options={options}
                onSelect={onSelect}
                styles={{ ...selectStyles }}
              />
            </div>
          )}
          {close && (
            <div className="close">
              <ButtonLink oClick={onClose}>{closeTitle}</ButtonLink>
              <FontAwesomeIcon icon={faTimes} />
            </div>
          )}
        </div>
      </div>
    </Nav>
  );
};

Navigationbar.propTypes = {
  /**
    Color of the navigation
   */
  color: PropType.string,
  /**
    Active the select
   */
  select: PropType.bool,
  /**
    Active the close button
   */
  close: PropType.bool,
  /**
    Title of the close button
   */
  closeTitle: PropType.string,
  /**
    Callback fuction of close button
   */
  onClose: PropType.func,
  /**
    Callback fuction of selected option
   */
  onSelect: PropType.func,
  /**
    Callback fuction of redirect logo action
   */
  onRedirect: PropType.func,
  /**
    Display the logo
   */
  logo: PropType.string.isRequired,
  /**
    Logo accessibility alt text
   */
  alt: PropType.string.isRequired,
  /**
    Options to be used on select
   */
  options: PropType.shape([
    {
      label: PropType.string.isRequired,
      value: PropType.string.isRequired,
    },
  ]),
};

Navigationbar.defaultProps = {
  alt: "Logo da empresa",
  color: "#027de9",
  select: false,
  close: false,
};
