import { useState, useEffect } from "react";
import PropType from "prop-types";

import AtlasSelect from "@atlaskit/select";
import { HelperMessage } from "@atlaskit/form";

import { Wrapper } from "./styles";

export const Select = ({
  title,
  helperText,
  name,
  options,
  defaultValue,
  onChange,
}) => {
  const [value, setValue] = useState(() => defaultValue || {});

  useEffect(() => {
    onChange(value);
  }, [value, onChange]);

  return (
    <Wrapper>
      <label htmlFor="atlasselect">{title}</label>
      <AtlasSelect
        id="atlasselect"
        classNamePrefix="react-select"
        name={name}
        value={value}
        defaultValue={defaultValue || {}}
        options={options}
        onChange={setValue}
      />
      <HelperMessage>{helperText}</HelperMessage>
    </Wrapper>
  );
};

Select.propType = {
  /**
   Title
   */
  title: PropType.string.isRequired,
  /**
   Name
   */
  name: PropType.string.isRequired,
  /**
  Options
   */
  options: PropType.shape([
    {
      label: PropType.string,
      value: PropType.string,
    },
  ]).isRequired,
  /**
   Helper text
   */
  helperText: PropType.string,
  /**
  Default value
   */
  defaultValue: PropType.shape({
    label: PropType.string,
    value: PropType.string,
  }),
  /**
   Callback function
   */
  onChange: PropType.func,
};
